@@ -5,7 +5,7 @@
 """Module for dealing with Git stashes."""
 
 
-import common
+from . import common
 
 import re
 
@@ -57,12 +57,12 @@ def _stash_id(msg):
     the stash id of the stash with the given msg or None if no matching stash is
     found.
   """
-  out, unused_err = common.safe_git_call('stash list --grep=": %s"' % msg)
+  out, _ = common.safe_git_call('stash list --grep=": %s"' % msg)
 
   if not out:
     return None
 
-  pattern = '(stash@\{.+\}): '
+  pattern = r'(stash@\{.+\}): '
   result = re.match(pattern, out)
   if not result:
     raise Exception('Unexpected output %s' % out)
